<?php

namespace App\Factory;

use App\Exception;

class PaymentFactory {
    
    private $connection;
    
    public function __construct (\Doctrine\DBAL\Connection $connection) {
        $this->connection = $connection;
    }
    
    public function getReceiptType ($receipt) {
        $sql = "
            SELECT CDTIPORECE
            FROM TIPORECEINTE TP
            JOIN INTEGRACAO INTE ON TP.CDINTEGRACAO = INTE.CDINTEGRACAO
            WHERE INTE.IDINTEGRACAO = :IDINTEGRACAO
              AND UPPER(REPLACE(CDTPRECEINTE, ' ', '')) = :CDTPRECEINTE";
        
        $params = array(
            ":CDTPRECEINTE" => strtoupper(preg_replace("/\s+/", "", $receipt)),
            ":IDINTEGRACAO" => "PED"
        );
        
        $result = $this->connection->fetchAll($sql, $params);
        
        if (empty($result))
            throw new Exception\ParamsException("Não foi encontrado tipo de recebimento para a origem - {$receipt}", 112);
        if (!isset($result[0]["CDTIPORECE"]))
            throw new Exception\ParamsException("Não foi encontrado tipo de recebimento para a origem - {$receipt}", 112);
        
        return $result[0]["CDTIPORECE"];
    }
    
    public function getMoneyReceiptCode () {
        $sql = "SELECT MIN(CDTIPORECE) AS CDTIPORECE
                FROM TIPORECE
                WHERE IDTIPORECE = '4'";
        
        $result = $this->connection->fetchAll($sql);
        
        return $result[0]["CDTIPORECE"];
    }
    
}
