<?php

namespace App\Service;

use App\Exception;

class DispatchService {
    
    private $connection;
    private $util;

    public function __construct (\Doctrine\DBAL\Connection $connection, \App\Util\Util $util) {
        $this->connection = $connection;
        $this->util = $util;
    }
    
    const GET_PENDING_DISPATCH_ORDERS = "
        SELECT CDFILIAL, NRCOMANDA, NRCOMANDAEXT, IDSTCOMANDA
          FROM COMANDAVEN
         WHERE CDFILIAL      IN(?)
           AND NRCOMANDA     IN(?)    
           AND NRCOMANDAEXT  IN(?)
           AND IDORGCMDVENDA  = 'DLV_PED'
    ";

    public function getPendingDispatchOrders($cdFilialArr, $nrComandaArr, $nrComandaExtArr) {
        $params = [
            $cdFilialArr,
            $nrComandaArr,
            $nrComandaExtArr
        ];
        
        $types = [\Doctrine\DBAL\Connection::PARAM_STR_ARRAY, 
                  \Doctrine\DBAL\Connection::PARAM_STR_ARRAY, 
                  \Doctrine\DBAL\Connection::PARAM_STR_ARRAY];
                  
        return $this->connection->fetchAll(self::GET_PENDING_DISPATCH_ORDERS, $params, $types);
    }

    public function registerPendingDispatchOrder($cdFilial, $nrComanda, $nrComandaExt, $reference, $orderType) {
        
        $pendingDispatchFile = $this->util->getPendingOrdersFile();
        if(!file_exists($pendingDispatchFile)) {
            file_put_contents($pendingDispatchFile, json_encode([], JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE));
        }
        
        $pendingDispatchFileContent = file_get_contents($pendingDispatchFile);
        $pendingDispatchData        = json_decode($pendingDispatchFileContent, true);
        
        $key = "$cdFilial|$nrComanda|$nrComandaExt";
        if(!isset($pendingDispatchData[$key])) {
            $pendingDispatchData[$key] = [
                'cdFilial'     => $cdFilial,
                'nrComanda'    => $nrComanda,
                'nrComandaExt' => $nrComandaExt,
                'orderType'    => $orderType,
                'dispatchedAt' => '',
                'delivered'    => false,
                'canceled'     => false,
                'createdAt'    => time()
            ];        
        }

        file_put_contents($pendingDispatchFile, json_encode($pendingDispatchData, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE));
    }
    
    public function registerTogoOrder($cdFilial, $nrComanda, $nrComandaExt, $reference, $impAuto) {
        $pendingDispatchFile = $this->util->getTogoOrdersFile();
        if(!file_exists($pendingDispatchFile)) {
            file_put_contents($pendingDispatchFile, json_encode([], JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE));
        }
        
        $pendingDispatchFileContent = file_get_contents($pendingDispatchFile);
        $pendingDispatchData        = json_decode($pendingDispatchFileContent, true);
        
        $key = "$cdFilial|$nrComanda|$nrComandaExt";
        if(!isset($pendingDispatchData[$key])) {
            $pendingDispatchData[$key] = [
                'cdFilial'     => $cdFilial,
                'nrComanda'    => $nrComanda,
                'nrComandaExt' => $nrComandaExt,
                'reference'    => $reference,
                'readyAt'      => '',
                'finished'     => false,
                'canceled'     => false,
                'createdAt'    => time()
            ];        
        }

        file_put_contents($pendingDispatchFile, json_encode($pendingDispatchData, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE));
    }
}
